@@ -27,6 +27,7 @@ static const char *get_sieve_path(void)
 			/* disabled */
 			return NULL;
 		}
+		script_path = home_expand(script_path);
 
 		if (*script_path != '/' && *script_path != '\0') {
 			/* relative path. change to absolute. */
@@ -35,10 +36,8 @@ static const char *get_sieve_path(void)
 		}
 	} else {
 		if (home == NULL) {
-			/* we must have a home directory */
-			i_error("userdb(%s) didn't return a home directory or "
-				"sieve script location, can't find it",
-				getenv("USER"));
+			i_error("Per-user script path is unknown. See "
+				"http://wiki.dovecot.org/LDA/Sieve#location");
 			return NULL;
 		}
 
